Module eval

Module eval 

Structs

AgentAssertionTask
AssertionResult
AssertionResults
AssertionTask
EvaluationTasks
LLMJudgeTask
Primary class for defining an LLM as a Judge in evaluation workflows
PyValueWrapper
TasksFile
TokenUsage
ToolCall
TraceAssertionTask

Enums

AgentAssertion
AggregationType
AssertionValue
AttributeFilterTask
Inner task to run on each extracted attribute value
ComparisonOperator
EvaluationTask
EvaluationTaskType
MultiResponseMode
Mode for aggregating results across multiple attribute values
PromptConfig
SpanFilter
Filter configuration for selecting spans to assert on
SpanStatus
TaskConfig
TraceAssertion
Unified assertion target that can operate on traces or filtered spans

Traits

ValueExt

Functions

assertion_value_from_py
Converts a PyAny value to an AssertionValue
deserialize_from_path