pub struct LLMJudgeTask {
pub id: String,
pub prompt: Prompt,
pub context_path: Option<String>,
pub expected_value: Value,
pub operator: ComparisonOperator,
pub task_type: EvaluationTaskType,
pub depends_on: Vec<String>,
pub max_retries: Option<u32>,
pub result: Option<AssertionResult>,
pub description: Option<String>,
pub condition: bool,
}Expand description
Primary class for defining an LLM as a Judge in evaluation workflows
Fields
id: Stringprompt: Promptcontext_path: Option<String>expected_value: Valueoperator: ComparisonOperatortask_type: EvaluationTaskTypedepends_on: Vec<String>max_retries: Option<u32>result: Option<AssertionResult>description: Option<String>condition: boolImplementations
Sourceimpl LLMJudgeTask
impl LLMJudgeTask
Sourcepub fn new(
id: &str,
prompt: Prompt,
expected_value: &Bound<'_, PyAny>,
context_path: Option<String>,
operator: ComparisonOperator,
description: Option<String>,
depends_on: Option<Vec<String>>,
max_retries: Option<u32>,
condition: Option<bool>,
) -> Result<Self, TypeError>
pub fn new( id: &str, prompt: Prompt, expected_value: &Bound<'_, PyAny>, context_path: Option<String>, operator: ComparisonOperator, description: Option<String>, depends_on: Option<Vec<String>>, max_retries: Option<u32>, condition: Option<bool>, ) -> Result<Self, TypeError>
Creates a new LLMJudgeTask
Examples
task = LLMJudgeTask(
id="Sentiment Analysis Judge",
prompt=prompt_object,
expected_value="Positive",
operator=ComparisonOperator.EQUALS
)
# Arguments
* `id: The id of the judge task
* `prompt`: The prompt object to be used for evaluation
* `expected_value`: The expected value for the judgement
* `context_path`: Optional context path to extract from the context for evaluation
* `operator`: The comparison operator to use
* `depends_on`: Optional list of task IDs this task depends on
* `max_retries`: Optional maximum number of retries for this task (defaults to 3 if not provided)
# Returns
A new LLMJudgeTask objectpub fn __str__(&self) -> String
pub fn get_expected_value<'py>( &self, py: Python<'py>, ) -> Result<Bound<'py, PyAny>, TypeError>
pub fn from_path(path: PathBuf) -> Result<Self, TypeError>
Sourceimpl LLMJudgeTask
impl LLMJudgeTask
Sourcepub fn new_rs(
id: &str,
prompt: Prompt,
expected_value: Value,
context_path: Option<String>,
operator: ComparisonOperator,
depends_on: Option<Vec<String>>,
max_retries: Option<u32>,
description: Option<String>,
condition: Option<bool>,
) -> Self
pub fn new_rs( id: &str, prompt: Prompt, expected_value: Value, context_path: Option<String>, operator: ComparisonOperator, depends_on: Option<Vec<String>>, max_retries: Option<u32>, description: Option<String>, condition: Option<bool>, ) -> Self
Creates a new LLMJudgeTask with Rust types
Arguments
- `id: The id of the judge task
prompt: The prompt object to be used for evaluationexpected_value: The expected value for the judgementcontext_path: Optional context path to extract from the context for evaluationoperator: The comparison operator to usedepends_on: Optional list of task IDs this task depends onmax_retries: Optional maximum number of retries for this task (defaults to 3 if not provided)
Returns
A new LLMJudgeTask object