pub struct AssertionTasks {
pub assertion: Vec<AssertionTask>,
pub judge: Vec<LLMJudgeTask>,
pub trace: Vec<TraceAssertionTask>,
}Fields
assertion: Vec<AssertionTask>judge: Vec<LLMJudgeTask>trace: Vec<TraceAssertionTask>Implementations
Sourceimpl AssertionTasks
impl AssertionTasks
pub fn collect_non_judge_task_ids(&self) -> BTreeSet<String>
pub fn collect_all_task_ids(&self) -> Result<BTreeSet<String>, TypeError>
Sourcepub fn from_tasks_file(tasks: TasksFile) -> Self
pub fn from_tasks_file(tasks: TasksFile) -> Self
this is meant to consume the tasks from TasksFile and convert them into AssertionTasks, separating them into assertion, judge, and trace tasks. It also validates that there are no duplicate task IDs across all tasks.